@@ -50,6 +50,7 @@
 package com.openexchange.drive.json.action;
 
 import java.util.List;
+import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -58,6 +59,7 @@ import com.openexchange.drive.DirectoryVersion;
 import com.openexchange.drive.DriveService;
 import com.openexchange.drive.SyncResult;
 import com.openexchange.drive.json.internal.DefaultDriveSession;
+import com.openexchange.drive.json.internal.DriveJSONUtils;
 import com.openexchange.drive.json.internal.Services;
 import com.openexchange.drive.json.json.JsonDirectoryVersion;
 import com.openexchange.drive.json.json.JsonDriveAction;
@@ -111,10 +113,17 @@ public class SyncFoldersAction extends AbstractDriveAction {
          */
         try {
             DriveService driveService = Services.getService(DriveService.class, true);
-            SyncResult<DirectoryVersion> syncResult = driveService.syncFolders(session, originalVersions, clientVersions);
-            if (null != session.isDiagnostics()) {
+            boolean includeQuota = requestData.containsParameter("quota") ? requestData.getParameter("quota", Boolean.class).booleanValue() : false;
+            SyncResult<DirectoryVersion> syncResult = driveService.syncFolders(session, originalVersions, clientVersions, includeQuota);
+            if (null != session.isDiagnostics() || includeQuota) {
                 JSONObject jsonObject = new JSONObject();
-                jsonObject.put("diagnostics", syncResult.getDiagnostics());
+                if (null != session.isDiagnostics()) { 
+                    jsonObject.put("diagnostics", syncResult.getDiagnostics());
+                }
+                if (includeQuota) {
+                    JSONArray quotaAsJSON = DriveJSONUtils.serializeQuota(syncResult.getQuota());
+                    jsonObject.put("quota", quotaAsJSON);
+                }
                 jsonObject.put("actions", JsonDriveAction.serializeActions(syncResult.getActionsForClient(), session.getLocale()));
                 return new AJAXRequestResult(jsonObject, "json");
             }
