@@ -66,6 +66,9 @@ public class DriveSettings {
     private String minApiVersion;
     private Map<String, String> localizedFolders;
     private Set<String> capabilities;
+    private Long minUploadChunk;
+    private int minSearchChars;
+    private boolean hasTrashFolder;
 
     /**
      * Initializes a new {@link DriveSettings}.
@@ -200,4 +203,58 @@ public class DriveSettings {
         this.capabilities = capabilities;
     }
 
+    /**
+     * Gets the minUploadChunk
+     *
+     * @return The minUploadChunk
+     */
+    public Long getMinUploadChunk() {
+        return minUploadChunk;
+    }
+
+    /**
+     * Sets the minUploadChunk
+     *
+     * @param minUploadChunk The minUploadChunk to set
+     */
+    public void setMinUploadChunk(Long minUploadChunk) {
+        this.minUploadChunk = minUploadChunk;
+    }
+
+    /**
+     * Gets the minSearchChars
+     *
+     * @return The minSearchChars
+     */
+    public int getMinSearchChars() {
+        return minSearchChars;
+    }
+
+    /**
+     * Sets the minSearchChars
+     *
+     * @param minSearchChars The minSearchChars to set
+     */
+    public void setMinSearchChars(int minSearchChars) {
+        this.minSearchChars = minSearchChars;
+    }
+
+    /**
+     * Gets the hasTrashFolder
+     *
+     * @return The hasTrashFolder
+     */
+    public boolean hasTrashFolder() {
+        return hasTrashFolder;
+    }
+
+    /**
+     * Sets the hasTrashFolder
+     *
+     * @param hasTrashFolder The hasTrashFolder to set
+     */
+    public void setHasTrashFolder(boolean hasTrashFolder) {
+        this.hasTrashFolder = hasTrashFolder;
+    }
+
 }
